@@ -2,8 +2,8 @@
 # vim: ts=4:sw=4:expandtab
 
 # BleachBit
-# Copyright (C) 2014 Andrew Ziem
-# http://sourceforge.net
+# Copyright (C) 2008-2015 Andrew Ziem
+# http://bleachbit.sourceforge.net
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -93,7 +93,7 @@ class TreeInfoModel:
             c_id = backends[key].get_id()
             c_value = options.get_tree(c_id, None)
             if not c_value and options.get('auto_hide') \
-                and backends[key].auto_hide():
+                    and backends[key].auto_hide():
                 print "info: automatically hiding cleaner '%s'" % (c_id)
                 continue
             parent = self.tree_store.append(None, (c_name, c_value, c_id))
@@ -311,8 +311,13 @@ class GUI:
     def run_operations(self, __widget):
         """Event when the 'delete' toolbar button is clicked."""
         # fixme: should present this dialog after finding operations
-        if not GuiBasic.delete_confirmation_dialog(self.window, True):
-            return
+
+        # Disable delete confirmation message.
+        # if the option is selected under preference.
+
+        if options.get("delete_confirmation"):
+            if not GuiBasic.delete_confirmation_dialog(self.window, True):
+                return
         self.preview_or_run_operations(True)
 
     def preview_or_run_operations(self, really_delete, operations=None):
@@ -353,6 +358,13 @@ class GUI:
         self.textview.scroll_mark_onscreen(self.textbuffer.get_insert())
         self.set_sensitive(True)
 
+        # Close the program after cleaning is completed.
+        # if the option is selected under preference.
+
+        if really_delete:
+            if options.get("exit_done"):
+                sys.exit()
+
         # notification for long-running process
         elapsed = (time.time() - self.start_time)
         print 'debug: elapsed time: %d seconds' % elapsed
@@ -378,7 +390,7 @@ class GUI:
                                           link: GuiBasic.open_url(link, self.window, False))
         dialog = gtk.AboutDialog()
         dialog.set_comments(_("Program to clean unnecessary files"))
-        dialog.set_copyright("Copyright (C) 2014 Andrew Ziem")
+        dialog.set_copyright("Copyright (C) 2008-2015 Andrew Ziem")
         try:
             dialog.set_license(open(license_filename).read())
         except:
@@ -489,7 +501,11 @@ class GUI:
         self.shred_paths(paths)
 
     def shred_paths(self, paths):
-        """Shred file or folders"""
+        """Shred file or folders
+
+        If user confirms and files are deleted, returns True.  If
+        user aborts, returns False.
+        """
         # create a temporary cleaner object
         backends['_gui'] = Cleaner.create_simple_cleaner(paths)
 
@@ -501,10 +517,13 @@ class GUI:
             # delete
             self.preview_or_run_operations(True, operations)
             return True
+
+        # user aborted
         return False
 
     def cb_shred_quit(self, action):
         """Shred settings (for privacy reasons) and quit"""
+        # build a list of paths to delete
         paths = []
         if portable_mode:
             # in portable mode on Windows, the options directory includes
@@ -513,14 +532,22 @@ class GUI:
         else:
             paths.append(options_dir)
 
+        # prompt the user to confirm
         if not self.shred_paths(paths):
+            print 'user aborted'
             # aborted
             return
 
+        # in portable mode, rebuild a minimal bleachbit.ini
         if portable_mode:
             open(options_file, 'w').write('[Portable]\n')
 
-        gtk.main_quit()
+        # Quit the application through the idle loop to allow the worker
+        # to delete the files.  Use the lowest priority because the worker
+        # uses the standard priority.  Otherwise, this will quit before
+        # the files are deleted.
+        gobject.idle_add(
+            lambda: gtk.main_quit(), priority=gobject.PRIORITY_LOW)
 
     def cb_wipe_free_space(self, action):
         """callback to wipe free space in arbitrary folder"""
@@ -686,6 +713,7 @@ class GUI:
         self.window.connect('destroy', lambda w: gtk.main_quit())
 
         self.window.resize(800, 600)
+        self.window.set_position(gtk.WIN_POS_CENTER)
         self.window.set_title(APP_NAME)
         if appicon_path and os.path.exists(appicon_path):
             self.window.set_icon_from_file(appicon_path)
@@ -795,7 +823,8 @@ class GUI:
                 self.append_text(
                     _("Error loading the SQLite module: the antivirus software may be blocking it."), 'error')
         if 'posix' == os.name and os.path.expanduser('~') == '/root':
-            self.append_text(_('You are running BleachBit with administrative privileges for cleaning shared parts of the system, and references to the user profile folder will clean only the root account.'))
+            self.append_text(
+                _('You are running BleachBit with administrative privileges for cleaning shared parts of the system, and references to the user profile folder will clean only the root account.'))
 
 
 if __name__ == '__main__':
