@@ -2,7 +2,7 @@
 # -*- coding: UTF-8 -*-
 
 # BleachBit
-# Copyright (C) 2014 Andrew Ziem
+# Copyright (C) 2008-2015 Andrew Ziem
 # http://bleachbit.sourceforge.net
 #
 # This program is free software: you can redistribute it and/or modify
@@ -29,6 +29,7 @@ import sys
 import unittest
 
 sys.path.append('.')
+import bleachbit.Common
 from bleachbit.Unix import *
 
 
@@ -68,13 +69,6 @@ class UnixTestCase(unittest.TestCase):
         exe = os.path.basename(os.path.realpath(sys.executable))
         self.assertTrue(is_running(exe))
 
-    def test_iterate_languages(self):
-        """Unit test for the method iterate_languages()"""
-        for language in self.locales.iterate_languages():
-            self.assert_(isinstance(language, str))
-            self.assert_(len(language) > 0)
-            self.assert_(len(language) < 9)
-
     def test_locale_to_language(self):
         """Unit test for locale_to_language()"""
         tests = [('en', 'en'),
@@ -116,8 +110,19 @@ class UnixTestCase(unittest.TestCase):
 
     def test_localization_paths(self):
         """Unit test for localization_paths()"""
-        for path in locales.localization_paths(lambda x, y: False):
+        from xml.dom.minidom import parseString
+        configpath = parseString(
+            '<path location="/usr/share/locale/" />').firstChild
+        locales.add_xml(configpath)
+        counter = 0
+        for path in locales.localization_paths(['en']):
             self.assert_(os.path.lexists(path))
+            # self.assert_(path.startswith('/usr/share/locale'))
+            # /usr/share/locale/en_* should be ignored
+            self.assert_(path.find('/en_') == -1)
+            counter += 1
+        self.assert_(
+            counter > 0, 'Zero files deleted by localization cleaner.  This may be an error unless you really deleted all the files.')
 
     def test_native_name(self):
         """Unit test for native_name()"""
@@ -136,6 +141,12 @@ class UnixTestCase(unittest.TestCase):
         """Unit test for start_with_computer*"""
         b = start_with_computer_check()
         self.assert_(isinstance(b, bool))
+
+        if not os.path.exists(bleachbit.Common.launcher_path) and \
+                os.path.exists('bleachbit.desktop'):
+            # this happens when BleachBit is not installed
+            bleachbit.Common.launcher_path = 'bleachbit.desktop'
+
         # opposite setting
         start_with_computer(not b)
         two_b = start_with_computer_check()
