@@ -1,7 +1,7 @@
 # vim: ts=4:sw=4:expandtab
 
 # BleachBit
-# Copyright (C) 2014 Andrew Ziem
+# Copyright (C) 2008-2015 Andrew Ziem
 # http://bleachbit.sourceforge.net
 #
 # This program is free software: you can redistribute it and/or modify
@@ -31,7 +31,7 @@ def destructive_tests(title):
     """Return true if allowed to run destructive tests.  If false print notice."""
     if os.getenv('DESTRUCTIVE_TESTS') == 'T':
         return True
-    print 'warning: skipping test(s) for %s because env. var. DESTRUCTIVE_TESTS not set' % title
+    print 'warning: skipping test(s) for %s because not getenv(DESTRUCTIVE_TESTS)=T' % title
     return False
 
 
